@@ -1,30 +1,30 @@
-#' Computing confidence intervals
+#' Compute confidence intervals
 #'
 #' @description
-#' This function computes confidence intervals for the estimates of an
-#' \code{fHMM_model} object using the inverse Fisher information.
+#' This helper function computes confidence intervals for the estimates of an
+#' \code{\link{fHMM_model}} object using the inverse Fisher information.
 #'
 #' @param x
-#' An object of class \code{fHMM_model}.
+#' An object of class \code{\link{fHMM_model}}.
 #'
 #' @param alpha
-#' The alpha level for the confidence interval, a numeric between 0 and 1. 
-#' Per default, \code{alpha = 0.05}, which computes a 95% confidence interval.
+#' A \code{numeric} between 0 and 1, the alpha level for the confidence interval.
+#' By default, \code{alpha = 0.05}, which computes a 95% confidence interval.
 #'
 #' @return
-#' A list containing the following elements:
+#' A \code{list} containing the following elements:
 #' \itemize{
 #'   \item \code{lb}: lower bound of confidence
 #'   \item \code{estimate}: point estimate
 #'   \item \code{ub}: upper bound of confidence
 #' }
 #'
-#' @keywords
-#' internal
+#' @keywords internal
 #'
 #' @examples
-#' data("dax_model_3t")
-#' fHMM:::compute_ci(x = dax_model_3t, alpha = 0.05)
+#' \dontrun{
+#' compute_ci(x = dax_model_3t, alpha = 0.05)
+#' }
 #'
 #' @importFrom stats qnorm
 
@@ -32,10 +32,10 @@ compute_ci <- function(x, alpha = 0.05) {
 
   ### check inputs
   if (!inherits(x,"fHMM_model")) {
-    stop("'x' must be of class 'fHMM_model'.", call. = FALSE)
+    stop("Input 'x' must be an 'fHMM_model' object.", call. = FALSE)
   }
   if (!is.numeric(alpha) || length(alpha) != 1 || alpha <= 0 || alpha >= 1) {
-    stop("'alpha' must be a numeric between 0 and 1.", call. = FALSE)
+    stop("Input 'alpha' must be a numeric between 0 and 1.", call. = FALSE)
   }
 
   ### compute confidence intervals using the inverse Hessian approach
@@ -61,13 +61,8 @@ compute_ci <- function(x, alpha = 0.05) {
     list(lower_limit, x$estimate, upper_limit),
     parUncon2parCon, x$data$controls
   )
-  if (anyNA(out)) {
-    warning(paste(
-      "Some confidence intervals could not be computed.",
-      "The corresponding estimates may lie close to the boundaries of their",
-      "parameter space, the confidence intervals may be unreliable and are",
-      "therefore replaced by 'NA_real_'."),
-    call. = FALSE)
+  if (anyNA(unlist(out))) {
+    warning("Some confidence intervals could not be computed.", call. = FALSE)
   }
   names(out) <- c("lb", "estimate", "ub")
   return(out)
